You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@arrow.apache.org by ko...@apache.org on 2022/08/16 07:22:37 UTC

[arrow] branch master updated: ARROW-17175: [CI][macOS] macos-10.15 is deprecated and macos-latest is macos-11 (#13684)

This is an automated email from the ASF dual-hosted git repository.

kou pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/arrow.git


The following commit(s) were added to refs/heads/master by this push:
     new 01358f117a ARROW-17175: [CI][macOS] macos-10.15 is deprecated and macos-latest is macos-11 (#13684)
01358f117a is described below

commit 01358f117a5d57388df51db482f2a72033a8efc4
Author: Sutou Kouhei <ko...@clear-code.com>
AuthorDate: Tue Aug 16 16:22:30 2022 +0900

    ARROW-17175: [CI][macOS] macos-10.15 is deprecated and macos-latest is macos-11 (#13684)
    
    https://github.com/actions/virtual-environments#available-environments
    
    > macOS 11 macos-latest or macos-11
    > macOS 10.15 deprecated macos-10.15
    
    Authored-by: Sutou Kouhei <ko...@clear-code.com>
    Signed-off-by: Sutou Kouhei <ko...@clear-code.com>
---
 .github/workflows/cpp.yml                    |  2 +-
 .github/workflows/csharp.yml                 |  2 +-
 .github/workflows/go.yml                     |  4 ++--
 .github/workflows/java.yml                   |  2 +-
 .github/workflows/js.yml                     |  2 +-
 .github/workflows/matlab.yml                 |  4 ++--
 .github/workflows/python.yml                 |  2 +-
 .github/workflows/ruby.yml                   |  2 +-
 ci/scripts/install_gcs_testbench.sh          |  8 ++++----
 dev/tasks/conda-recipes/azure.osx.yml        |  2 +-
 dev/tasks/homebrew-formulae/github.macos.yml |  2 +-
 dev/tasks/python-wheels/github.osx.amd64.yml | 12 ++++++------
 dev/tasks/tasks.yml                          |  6 +++---
 13 files changed, 25 insertions(+), 25 deletions(-)

diff --git a/.github/workflows/cpp.yml b/.github/workflows/cpp.yml
index ba95fcd509..967b57fed8 100644
--- a/.github/workflows/cpp.yml
+++ b/.github/workflows/cpp.yml
@@ -119,7 +119,7 @@ jobs:
           docker-compose run --rm minimal
 
   macos:
-    name: AMD64 MacOS 10.15 C++
+    name: AMD64 macOS 11 C++
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 60
diff --git a/.github/workflows/csharp.yml b/.github/workflows/csharp.yml
index 385c081cc6..8f34db9708 100644
--- a/.github/workflows/csharp.yml
+++ b/.github/workflows/csharp.yml
@@ -91,7 +91,7 @@ jobs:
         run: ci/scripts/csharp_test.sh $(pwd)
 
   macos:
-    name: AMD64 MacOS 10.15 C# ${{ matrix.dotnet }}
+    name: AMD64 macOS 11 C# ${{ matrix.dotnet }}
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 15
diff --git a/.github/workflows/go.yml b/.github/workflows/go.yml
index f3fa866c86..4112bf3bd4 100644
--- a/.github/workflows/go.yml
+++ b/.github/workflows/go.yml
@@ -186,7 +186,7 @@ jobs:
         run: ci/scripts/go_test.sh $(pwd)
 
   macos:
-    name: AMD64 MacOS 10.15 Go ${{ matrix.go }}
+    name: AMD64 macOS 11 Go ${{ matrix.go }}
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 15
@@ -221,7 +221,7 @@ jobs:
         run: ci/scripts/go_test.sh $(pwd)
 
   macos-cgo:
-    name: AMD64 MacOS 10.15 Go ${{ matrix.go }} - CGO
+    name: AMD64 macOS 11 Go ${{ matrix.go }} - CGO
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 60
diff --git a/.github/workflows/java.yml b/.github/workflows/java.yml
index 1cba010489..bd4f94147f 100644
--- a/.github/workflows/java.yml
+++ b/.github/workflows/java.yml
@@ -101,7 +101,7 @@ jobs:
         run: archery docker push ${{ matrix.image }}
 
   macos:
-    name: AMD64 MacOS 10.15 Java JDK ${{ matrix.jdk }}
+    name: AMD64 macOS 11 Java JDK ${{ matrix.jdk }}
     runs-on: macos-latest
     if: github.event_name == 'push'
     timeout-minutes: 30
diff --git a/.github/workflows/js.yml b/.github/workflows/js.yml
index 18d54c5b4e..0d7263e8a7 100644
--- a/.github/workflows/js.yml
+++ b/.github/workflows/js.yml
@@ -68,7 +68,7 @@ jobs:
         run: archery docker push debian-js
 
   macos:
-    name: AMD64 MacOS 10.15 NodeJS ${{ matrix.node }}
+    name: AMD64 macOS 11 NodeJS ${{ matrix.node }}
     runs-on: macos-latest
     if: github.event_name == 'push'
     timeout-minutes: 60
diff --git a/.github/workflows/matlab.yml b/.github/workflows/matlab.yml
index 3780ba113a..477582edb8 100644
--- a/.github/workflows/matlab.yml
+++ b/.github/workflows/matlab.yml
@@ -69,11 +69,11 @@ jobs:
         with:
           select-by-folder: matlab/test
   macos:
-    name: AMD64 MacOS 10.15 MATLAB
+    name: AMD64 macOS 11 MATLAB
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     steps:
-      - name: Check out repository        
+      - name: Check out repository
         uses: actions/checkout@v3
         with:
           fetch-depth: 0
diff --git a/.github/workflows/python.yml b/.github/workflows/python.yml
index fe834a55e6..5ccbceabea 100644
--- a/.github/workflows/python.yml
+++ b/.github/workflows/python.yml
@@ -113,7 +113,7 @@ jobs:
         run: archery docker push ${{ matrix.image }}
 
   macos:
-    name: AMD64 MacOS 10.15 Python 3
+    name: AMD64 macOS 11 Python 3
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 60
diff --git a/.github/workflows/ruby.yml b/.github/workflows/ruby.yml
index bf49376c6f..3f877b4aa3 100644
--- a/.github/workflows/ruby.yml
+++ b/.github/workflows/ruby.yml
@@ -102,7 +102,7 @@ jobs:
         run: archery docker push ubuntu-ruby
 
   macos:
-    name: AMD64 MacOS 10.15 GLib & Ruby
+    name: AMD64 macOS 11 GLib & Ruby
     runs-on: macos-latest
     if: ${{ !contains(github.event.pull_request.title, 'WIP') }}
     timeout-minutes: 60
diff --git a/dev/tasks/conda-recipes/azure.osx.yml b/dev/tasks/conda-recipes/azure.osx.yml
index 505a17cebe..404d6daee3 100755
--- a/dev/tasks/conda-recipes/azure.osx.yml
+++ b/dev/tasks/conda-recipes/azure.osx.yml
@@ -3,7 +3,7 @@
 jobs:
 - job: osx
   pool:
-    vmImage: macOS-10.15
+    vmImage: macOS-latest
   timeoutInMinutes: 360
   variables:
     CONFIG: {{ config }}
diff --git a/dev/tasks/homebrew-formulae/github.macos.yml b/dev/tasks/homebrew-formulae/github.macos.yml
index 3abb1d4525..fd69473757 100644
--- a/dev/tasks/homebrew-formulae/github.macos.yml
+++ b/dev/tasks/homebrew-formulae/github.macos.yml
@@ -22,7 +22,7 @@
 jobs:
   homebrew:
     name: "Homebrew"
-    runs-on: macOS-latest
+    runs-on: macos-latest
     steps:
       {{ macros.github_checkout_arrow()|indent }}
 
diff --git a/dev/tasks/python-wheels/github.osx.amd64.yml b/dev/tasks/python-wheels/github.osx.amd64.yml
index f83a4c1bf5..981ce7f50f 100644
--- a/dev/tasks/python-wheels/github.osx.amd64.yml
+++ b/dev/tasks/python-wheels/github.osx.amd64.yml
@@ -34,8 +34,8 @@ env:
 
 jobs:
   build:
-    name: Build wheel for OS X
-    runs-on: macos-10.15
+    name: Build wheel for macOS
+    runs-on: macos-latest
     env:
       VCPKG_BINARY_SOURCES: 'clear;nuget,GitHub,readwrite'
     steps:
@@ -65,9 +65,9 @@ jobs:
 
       - name: Setup NuGet Credentials
         shell: bash
-        env: 
+        env:
           GITHUB_TOKEN: {{ '${{ secrets.GITHUB_TOKEN }}' }}
-        run: |          
+        run: |
           mono `vcpkg fetch nuget | tail -n 1` \
             sources add \
             -source "https://nuget.pkg.github.com/$GITHUB_REPOSITORY_OWNER/index.json" \
@@ -75,11 +75,11 @@ jobs:
             -name "GitHub" \
             -username "$GITHUB_REPOSITORY_OWNER" \
             -password "$GITHUB_TOKEN" \
-          
+
           mono `vcpkg fetch nuget | tail -n 1` \
             setapikey "$GITHUB_TOKEN" \
             -source "https://nuget.pkg.github.com/$GITHUB_REPOSITORY_OWNER/index.json"
-          
+
       - name: Install Packages
         run: |
           if [ "${ARROW_S3}" == "ON" ]; then
diff --git a/dev/tasks/tasks.yml b/dev/tasks/tasks.yml
index 2194a627ba..a07c4d878c 100644
--- a/dev/tasks/tasks.yml
+++ b/dev/tasks/tasks.yml
@@ -1040,7 +1040,7 @@ tasks:
     params:
       target: {{ target }}
       use_conda: True
-      github_runner: "macos-10.15"
+      github_runner: "macos-latest"
   {% endfor %}
 
   {% for target in ["cpp",
@@ -1056,7 +1056,7 @@ tasks:
     template: verify-rc/github.macos.amd64.yml
     params:
       target: {{ target }}
-      github_runner: "macos-10.15"
+      github_runner: "macos-latest"
   {% endfor %}
 
   {% for target in ["cpp",
@@ -1080,7 +1080,7 @@ tasks:
       github_runner: ["self-hosted", "macOS", "arm64"]
   {% endfor %}
 
-  {% for macos_version in ["10.15", "11"] %}
+  {% for macos_version in ["11", "12"] %}
   verify-rc-binaries-wheels-macos-{{ macos_version }}-amd64:
     ci: github
     template: verify-rc/github.macos.amd64.yml
diff --git a/ci/scripts/install_gcs_testbench.sh b/ci/scripts/install_gcs_testbench.sh
index f7fa6e611d..0e56310662 100755
--- a/ci/scripts/install_gcs_testbench.sh
+++ b/ci/scripts/install_gcs_testbench.sh
@@ -38,20 +38,20 @@ case "$(uname -s)-$(uname -m)" in
   Darwin-arm64)
     # Workaround for https://github.com/grpc/grpc/issues/28387 .
     # Build grpcio instead of using wheel.
-    # storage-testbench 0.16.0 pins grpcio to 1.44.0.
-    ${PYTHON:-python3} -m pip install --no-binary :all: "grpcio==1.44.0"
+    # storage-testbench 0.27.0 pins grpcio to 1.46.1.
+    ${PYTHON:-python3} -m pip install --no-binary :all: "grpcio==1.46.1"
     ;;
   *_NT-*)
     # Mingw-w64: MSYS_NT-10.0-19043, MINGW32_NT-10.0-19043, MINGW64_NT-10.0-19043
     # Don't use the "/MT" option because g++ doesn't recognize it.
     # "/MT" is for Visual Studio.
-    GRPC_PYTHON_CFLAGS=" " ${PYTHON:-python3} -m pip install "grpcio==1.44.0"
+    GRPC_PYTHON_CFLAGS=" " ${PYTHON:-python3} -m pip install "grpcio==1.46.1"
     ;;
 esac
 
 version=$1
 if [[ "${version}" -eq "default" ]]; then
-  version="v0.16.0"
+  version="v0.27.0"
 fi
 
 ${PYTHON:-python3} -m pip install \